diff --git a/README.md b/README.md
index ae99de4f..a9e2434c 100644
--- a/README.md
+++ b/README.md
@@ -12,7 +12,6 @@ We have separate folders for the samples of individual modules:
* `example` - Probably the project you want to have a look at first. Contains a variety of sample packages, showcasing the different levels at which you can use Spring Data JPA. Have a look at the `simple` package for the most basic setup.
* `interceptors` - Example of how to enrich the repositories with AOP.
* `java8` - Example of how to use Spring Data JPA auditing with Java 8 date time types as well as the usage of `Optional` as return type for repository methods. Note, this project requires to be build with JDK 8.
-* `javaslang` - Shows the support of Javaslang collection types as return types for query methods (deprecated, see the Vavr module).
* `jpa21` - Shows support for JPA 2.1 specific features (stored procedures support).
* `multiple-datasources` - Examples of how to use Spring Data JPA with multiple `DataSource`s.
* `query-by-example` - Example project showing usage of Query by Example with Spring Data JPA.
diff --git a/jpa/pom.xml b/jpa/pom.xml
index bf7ef47b..ba250117 100644
--- a/jpa/pom.xml
+++ b/jpa/pom.xml
@@ -21,12 +21,12 @@
showcase
interceptors
java8
- javaslang
jpa21
security
multiple-datasources
eclipselink
query-by-example
+ vavr
diff --git a/jpa/javaslang/pom.xml b/jpa/vavr/pom.xml
similarity index 70%
rename from jpa/javaslang/pom.xml
rename to jpa/vavr/pom.xml
index 4aa5641b..aa73fe84 100644
--- a/jpa/javaslang/pom.xml
+++ b/jpa/vavr/pom.xml
@@ -8,14 +8,14 @@
2.0.0.BUILD-SNAPSHOT
- spring-data-jpa-javaslang
- Spring Data JPA - Javaslang integration
+ spring-data-jpa-vavr
+ Spring Data JPA - Vavr integration
- io.javaslang
- javaslang
- 2.0.5
+ io.vavr
+ vavr
+ 0.9.1
diff --git a/jpa/javaslang/src/main/java/example/Person.java b/jpa/vavr/src/main/java/example/Person.java
similarity index 100%
rename from jpa/javaslang/src/main/java/example/Person.java
rename to jpa/vavr/src/main/java/example/Person.java
diff --git a/jpa/javaslang/src/main/java/example/PersonRepository.java b/jpa/vavr/src/main/java/example/PersonRepository.java
similarity index 72%
rename from jpa/javaslang/src/main/java/example/PersonRepository.java
rename to jpa/vavr/src/main/java/example/PersonRepository.java
index d96cb68e..24e3d1f6 100644
--- a/jpa/javaslang/src/main/java/example/PersonRepository.java
+++ b/jpa/vavr/src/main/java/example/PersonRepository.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2016 the original author or authors.
+ * Copyright 2016-2017 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@
*/
package example;
-import javaslang.collection.Map;
-import javaslang.collection.Seq;
-import javaslang.collection.Set;
-import javaslang.control.Option;
+import io.vavr.collection.Map;
+import io.vavr.collection.Seq;
+import io.vavr.collection.Set;
+import io.vavr.control.Option;
import java.util.List;
import java.util.Optional;
@@ -26,8 +26,8 @@ import java.util.Optional;
import org.springframework.data.repository.Repository;
/**
* Repository interface showing the usage of Javaslang collections and its {@link Option} type as repository query
* method return types.
*
* @author Oliver Gierke
*/
@@ -44,8 +44,8 @@ public interface PersonRepository extends Repository {
Option findById(Long id);
/**
* {@link Seq} can be used as alternative to JDK's {@link List}. Javaslang's {@link Set} and {@link Map} are
* supported, too, and transparently mapped from their JDK counterparts.
*
* @param firstname
* @return
@@ -26,8 +26,8 @@ import java.util.Optional;
import org.springframework.data.repository.Repository;
/**
- * Repository interface showing the usage of Javaslang collections and its {@link Option} type as repository query
- * method return types.
+ * Repository interface showing the usage of Vavr collections and its {@link Option} type as repository query method
+ * return types.
*
* @author Oliver Gierke
@@ -44,8 +44,8 @@ public interface PersonRepository extends Repository {
Option findById(Long id);
/**
- * {@link Seq} can be used as alternative to JDK's {@link List}. Javaslang's {@link Set} and {@link Map} are
- * supported, too, and transparently mapped from their JDK counterparts.
+ * {@link Seq} can be used as alternative to JDK's {@link List}. Vavr's {@link Set} and {@link Map} are supported,
+ * too, and transparently mapped from their JDK counterparts.
*
* @param firstname
diff --git a/jpa/javaslang/src/test/java/example/PersonRepositoryIntegrationTests.java b/jpa/vavr/src/test/java/example/PersonRepositoryIntegrationTests.java
similarity index 89%
rename from jpa/javaslang/src/test/java/example/PersonRepositoryIntegrationTests.java
rename to jpa/vavr/src/test/java/example/PersonRepositoryIntegrationTests.java
index d1630f7a..bace6559 100644
--- a/jpa/javaslang/src/test/java/example/PersonRepositoryIntegrationTests.java
+++ b/jpa/vavr/src/test/java/example/PersonRepositoryIntegrationTests.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2016 the original author or authors.
+ * Copyright 2016-2017 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@ package example;
import static org.assertj.core.api.Assertions.*;
-import javaslang.collection.Seq;
-import javaslang.control.Option;
+import io.vavr.collection.Seq;
+import io.vavr.control.Option;
import org.junit.Test;
import org.junit.runner.RunWith;
@@ -29,7 +29,7 @@ import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;
/**
* Integration tests for {@link PersonRepository} showing Javaslang support at repsoitory query methods.
*
* @author Oliver Gierke
*/
@@ -29,7 +29,7 @@ import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;
/**
- * Integration tests for {@link PersonRepository} showing Javaslang support at repsoitory query methods.
+ * Integration tests for {@link PersonRepository} showing Vavr support at repository query methods.
*
* @author Oliver Gierke